pmrun(1)

pmrun - graphical utility for entering PCP command line arguments

As shipped in IRIX 6.5. First release of IRIX 6.5.

NAME
     pmrun - graphical utility for entering PCP command line arguments

SYNOPSIS
     /usr/pcp/bin/pmrun [-a archive] [-h host] [-S start] [-T finish] [-t
     delta] [-x text] [-y text] command [specifications ...]

DESCRIPTION
     pmrun is a configurable utility for launching applications within the
     Performance Co-Pilot (PCP) framework.  It is primarily a visual interface
     to the more frequently used command line arguments for each tool, and is
     intended as an aid in launching tools from the desktop.

     pmrun is based on the launch(1) utility, and also understands a small set
     of the common PCP command line arguments, and contains knowledge of the
     semantics of these arguments.  For example, the arguments for archives
     (-a) and hosts (-h) are common to many of the PCP monitor tools, and are
     also mutually exclusive arguments - this relationship is enforced by
     pmrun, while still allowing either type of metric source to be specified.
     pmrun must be run with a command (must be an executable file) which is to
     be executed when either the ``OK'' or ``Apply'' button is pressed.

     The optional specifications allow additional launch arguments to be
     mapped to input fields for user completion.  Again, this is intended to
     provide a more obvious, self-explanatory interface to the launched
     application than is provided by the command line.

     The options control the specific arguments which are presented to the
     launched tool when either the ``OK'' or ``Apply'' button is pressed.

     -a   Creates a finder widget which allows an archive filename to be
          entered and subsequently passed to the launched tool via its own -a
          argument.  The default value presented in the finder will be
          archive, which can be the empty string (archive is required if pmrun
          is given the -a argument, even if an empty string enclosed by quotes
          is all that is used).

     -h   Creates a finder widget which allows a hostname to be entered and
          passed to the launched tool via its own -h argument.  The default
          value in the finder will be host.

     -S   Creates a text field which allows the start time for metric fetches
          from an archive to be entered.  This field will not be editable if
          both the -h and -a arguments have been presented to pmrun and the
          ``Host'' toggle button is currently set.  The times entered in this
          text field validated according to the syntax rules described in
          PCPIntro(1) before being passed on to the launched tool.

     -T   Similar to the -S argument, but allows the archive finish time to be
          entered.
     -t   Creates a text field and an associated time-units selection menu.
          This allows the sample interval at which performance metrics will be
          fetched from the metrics source to be specified.  The interval
          argument follows the syntax described in PCPIntro(1), and in the
          simplest form may be an unsigned integer (the implied units are
          seconds).  The default is 2.0 seconds.

     -x   The text following this argument will be prepended to the launched
          command before it is executed.

     -y   The text following this argument will be appended to the launched
          command before it is executed.

SPECIFICATION LANGUAGE
     The language used to recognize the specification arguments to pmrun is
     designed to be simple and easily extended (programmatically) should the
     need for different argument input mechanisms arise.

     The general format for these arguments is a ``|'' separated string, with
     the first argument distinguishing the user-interface element (type) which
     is to be created.  Currently the only supported specification type is for
     text fields, and the remaining tokens are as follows:

     text|flag|label|default

     The text token identifies this as a text field.  flag is the command line
     flag to pass to the launched application (a ``-'' will be prepended to
     this by pmrun) when a value has been entered into this text field.  label
     is the label associated with this text field, and default is the string
     displayed by default in the text field.

FILES
     /use/lib/X11/app-defaults/PmRun
                             application resources

SEE ALSO
     fftr(1), iconbook(1), launch(1) and PCPIntro(1).

DIAGNOSTICS
     All error conditions encountered will be reported via an error dialog,
     and are intended to be self-explanatory.